@@ -383,9 +383,8 @@ class TimeSeriesMetadata:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         metadata = TimeSeriesMetadata_pb2.TimeSeriesMetadata()
-        metadata.ParseFromString(byte_array)
+        metadata.ParseFromString(serialized)
         self._read_proto_object(metadata)
 
     def _read_proto_object(self,
@@ -397,6 +396,7 @@ class TimeSeriesMetadata:
         :type metadata: TimeSeriesMetadata_pb2.TimeSeriesMetadata
         """
         self._source = metadata.source
+        self._source = metadata.source
         self._category = metadata.category
         self._label = metadata.label
         self._url = metadata.url
@@ -727,9 +727,8 @@ class TimeSeriesData:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         time_series_data = TimeSeriesData_pb2.TimeSeriesData()
-        time_series_data.ParseFromString(byte_array)
+        time_series_data.ParseFromString(serialized)
         self._read_proto_object(time_series_data)
 
     def _read_proto_object(self,
@@ -909,9 +908,8 @@ class TimeSeries:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         time_series = TimeSeries_pb2.TimeSeries()
-        time_series.ParseFromString(byte_array)
+        time_series.ParseFromString(serialized)
         self._read_proto_object(time_series)
 
     def _read_proto_object(self,
@@ -1098,9 +1096,8 @@ class TimeSeriesMetadataRequest:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         request = TimeSeriesMetadataRequest_pb2.TimeSeriesMetadataRequest()
-        request.ParseFromString(byte_array)
+        request.ParseFromString(serialized)
         self._read_proto_object(request)
 
     def _read_proto_object(self, metadata_request: TimeSeriesMetadataRequest_pb2.TimeSeriesMetadataRequest):
@@ -1578,9 +1575,8 @@ class TimeSeriesRequest:
         :param serialized: bytes produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         request = TimeSeriesRequest_pb2.TimeSeriesRequest()
-        request.ParseFromString(byte_array)
+        request.ParseFromString(serialized)
         self._read_proto_object(request)
 
     @staticmethod
